@@ -11,7 +11,7 @@ function AutocompleteDeck(el) {
         return result.data('value');
     };
     this.initializeAutocomplete = function() {
-        this.input.yourlabs_autocomplete(this.autocompleteOptions);
+        this.autocomplete = this.input.yourlabs_autocomplete(this.autocompleteOptions);
     };
     this.bindSelectOption = function() {
         this.input.bind('selectOption', function(e, option) {
@@ -34,9 +34,12 @@ function AutocompleteDeck(el) {
         }
     }
     this.updateDisplay = function() {
+        this.input.val('');
+
         if (this.payload.max_items && this.valueSelect.find('option').length == this.payload.max_items) {
             this.input.hide();
-            this.input.val('');
+        } else {
+            this.input.show();
         }
 
         this.deck.show();
